@@ -1,6 +1,4 @@
-//  $Id: dinifti.cc,v 1.51 2008/01/22 19:18:54 valerio Exp $
-
-#define VERSION "2.28.11"
+#define VERSION "2.28.14"
 
 //****************************************************************************
 //
@@ -343,10 +341,9 @@ int main(int argc, char **argv)
 
 	SERIESMAP seriesMap;
 
-	StoreImageFiles(dicomFiles, seriesMap, argv[outNameIndex], opts);
-	
+	StoreImageFiles(dicomFiles, seriesMap, argv[outNameIndex], opts);	
 
-	// Turn offf excessive nifti messages
+	// Turn off excessive nifti messages
 
 	nifti_set_debug_level(0);
 	
@@ -432,14 +429,14 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 			{
 				acqNum = ((imgNum - 1) / opts.numSlices) + 1;
 			}
-			else if ( !dcmImg->Mosaic() && (dcmImg->NumSlices() > 1) )
-			{
-				acqNum = ((imgNum - 1) / dcmImg->NumSlices()) + 1;
-			}
 			else if ( !dcmImg->Mosaic() && (dcmImg->ACQEchoNumber() > 0) )
 			{
 				acqNum = dcmImg->ACQEchoNumber() + 1;
 			}
+			else if ( !dcmImg->Mosaic() && (dcmImg->NumSlices() > 1) )
+			{
+				acqNum = ((imgNum - 1) / dcmImg->NumSlices()) + 1;
+			}
 			else
 				acqNum = dcmImg->ACQNumber();
 
@@ -704,7 +701,7 @@ void ProcessSeries(SeriesInfo &seriesInfo, const DiniftiOptions& opts)
 
 	nifti_image niftiHdr;
 	if (! NIfTICreateHeader(niftiHdr, seriesInfo.imageMap))
-		exit(1);
+		return;
 	niftiHdr.nifti_type = (int)opts.niftiFormat;
 
 	// main processing loop over the repeat counters
@@ -723,23 +720,18 @@ void ProcessSeries(SeriesInfo &seriesInfo, const DiniftiOptions& opts)
 		
 		if (outfp == NULL)
 		{
-			exit(1);
+			cerr << "Writing output header failed for " << niftiHdr.fname
+				 << ". Continuing to next series." << endl << endl;
 		}
-				
-		if (! NIfTIWriteData(outfp, niftiHdr, seriesInfo.imageMap) )
+		else
 		{
-			cerr << "Writing output file failed, aborting." << endl << endl;
+			NIfTIWriteData(outfp, niftiHdr, seriesInfo.imageMap);
 			znzclose(outfp);
-			exit(1);
 		}
-
-		znzclose(outfp);
 	}
 
 	// Clean up time
 
 	delete [] niftiHdr.fname;
 	if (niftiHdr.iname != NULL) delete [] niftiHdr.iname;
-
-
 }
